# mimo-sms Python

[![](https://img.shields.io/badge/mimosms-OpenSource-blue.svg)]("https://www.mimo.it.ao/pt")

A Python library that offers integration with the MIMO SMS text messaging service. A simple way to add SMS notification support to your projects.

Work in progress.

## Note

All other resources are accessed in the same way by importing a resource class and calling only the class's methods to interact with the resource's data.

## License

The library is available as open source under the terms of the MIT License.
